
#!/bin/bash

#$ -N improve_ZJ
#$ -cwd
#$ -o ../logs/ZJ_improve.$JOB_ID.log
#$ -e ../logs/ZJ_improve.$JOB_ID.err
#$ -pe smp 1
#$ -l h_vmem=20G

###################################
GENOME=/mnt/data/arslan/Teas/01_Assembly/scaffolding/ZJ-scaffold/ZJ_rename.scaffold.fasta

ln -s /mnt/data/arslan/Teas/03_Annotation/Gene_finding/Helixer/ZJ/ZJ.90-60.gff3
ln -s /mnt/data/arslan/Teas/03_Annotation/Gene_finding/Mapping/output/Stringtie_ZJ/ZJ_IL_c50.gtf
ln -s /mnt/data/arslan/tool/Database/uniprot-swissprot-Viridiplantae.fasta

export PATH="/mnt/bin/gffread/gffread-0.12.4/:$PATH"
export PATH="/mnt/bin/blast+/ncbi-blast-2.9.0+/bin/:$PATH"
export PATH="/mnt/bin/prodigal/prodigal-2.6.3/:$PATH"
export PATH="/mnt/bin/samtools/samtools-1.13/:$PATH"


/mnt/bin/mikado/Mikado-2.3.0/mikado/bin/mikado configure --list list.ZJ --reference ${GENOME} --mode permissive --scoring plant.yaml  --copy-scoring plant.yaml \
-bt uniprot-swissprot-Viridiplantae.fasta configuration.yaml

conda activate mikado-env
mikado prepare --json-conf configuration.yaml -o mikado_prepared.gtf -of mikado_prepared.fasta

samtools faidx uniprot-swissprot-Viridiplantae.fasta
makeblastdb -in uniprot-swissprot-Viridiplantae.fasta -dbtype prot -parse_seqids

blastx -max_target_seqs 5 -outfmt "6 qseqid sseqid pident length mismatch gapopen qstart qend sstart send evalue bitscore ppos btop"
-num_threads ${NSLOTS} -query mikado_prepared.fasta -db uniprot-swissprot-Viridiplantae.fasta -out mikado_prepared.blast.tsv

prodigal -i mikado_prepared.fasta -g 1 -o mikado.orfs.gff3 -f gff


mikado serialise --json-conf configuration.yaml --tsv mikado_prepared.blast.tsv --transcripts mikado_prepared.fasta \
--orfs mikado.orfs.gff3 --blast-targets uniprot-swissprot-Viridiplantae.fasta --codon-table 1

mikado pick --configuration configuration.yaml --subloci-out mikado.subloci.gff3 --codon-table 1 --sqlite-db mikado.db

gffread mikado.loci.gff3 -g ${GENOME} -x mikado.loci_CDS.fa -y mikado.loci_prot.faa
