#!/usr/bin/env python

import sys
from Bio import SeqIO
from Bio.Seq import Seq

print("Usage: python Fixchr4SyRi.py chromosomelist.txt Input.fasta Output.fasta")

chromosomes_file = sys.argv[1]  # Path to the file containing the list of chromosomes to reverse
fasta_file = sys.argv[2]  # Path to the FASTA file containing the sequences
out_file = sys.argv[3] # Path to output fasta file

def reverse_chromosomes(chromosomes_file, fasta_file):
    # Read the list of chromosomes to reverse from the file
    with open(chromosomes_file, 'r') as file:
        chromosomes_to_reverse = [line.strip() for line in file]

    # Load the sequences from the FASTA file
    sequences = SeqIO.to_dict(SeqIO.parse(fasta_file, "fasta"))

    # Reverse the specified chromosomes
    for chromosome_id in chromosomes_to_reverse:
        if chromosome_id in sequences:
            sequence = sequences[chromosome_id].seq
            reverse_sequence = sequence.reverse_complement()
            sequences[chromosome_id].seq = reverse_sequence

    # Save the modified sequences to a new FASTA file
    reverse_file = out_file
    SeqIO.write(list(sequences.values()), reverse_file, "fasta")

    print("Reverse sequences created and saved to:", reverse_file)


reverse_chromosomes(chromosomes_file, fasta_file)
